Tomba

Struct Tomba 

pub struct Tomba { /* private fields */ }
The Tomba API client.

Create an instance with Tomba::init, then call the endpoint methods such as Tomba::account, Tomba::domain_search, etc.

Implementations

Source

impl Tomba

pub fn account(&self) -> Result<TombaResponse, TombaError>

Returns information about the current account.

See https://developer.tomba.io/#account

Source

impl Tomba

pub fn list_bulk(&self, bulk_type: &str) -> Result<TombaResponse, TombaError>

List all bulk tasks of a given type.

See https://developer.tomba.io/#list-all-bulk

pub fn get_bulk( &self, bulk_type: &str, id: &str, ) -> Result<TombaResponse, TombaError>

Get a single bulk task by type and ID.

See https://developer.tomba.io/#get-a-bulk

pub fn create_bulk( &self, bulk_type: &str, body: &Value, ) -> Result<TombaResponse, TombaError>

Create a new bulk task.

See https://developer.tomba.io/#create-a-bulk

pub fn launch_bulk( &self, bulk_type: &str, id: &str, ) -> Result<TombaResponse, TombaError>

pub fn delete_bulk( &self, bulk_type: &str, id: &str, ) -> Result<TombaResponse, TombaError>

pub fn archive_bulk( &self, bulk_type: &str, id: &str, ) -> Result<TombaResponse, TombaError>

pub fn rename_bulk( &self, bulk_type: &str, id: &str, name: &str, ) -> Result<TombaResponse, TombaError>

pub fn bulk_progress( &self, bulk_type: &str, id: &str, ) -> Result<TombaResponse, TombaError>

Get progress of a bulk task.

See https://developer.tomba.io/#bulk-progress

pub fn bulk_download( &self, bulk_type: &str, id: &str, ) -> Result<TombaResponse, TombaError>

Download results of a bulk task.

See https://developer.tomba.io/#bulk-download

Source

impl Tomba

pub fn count(&self, domain: &str) -> Result<TombaResponse, TombaError>

Returns the total number of email addresses Tomba has for a domain.

See https://developer.tomba.io/#email-count

Source

impl Tomba

Search emails for a domain.

Returns all email addresses found on the internet for the given domain.

See https://developer.tomba.io/#domain-search

Source

impl Tomba

pub fn person_find(&self, email: &str) -> Result<TombaResponse, TombaError>

Enrich a person by email address.

See https://developer.tomba.io/#enrichment

pub fn company_find(&self, domain: &str) -> Result<TombaResponse, TombaError>

Enrich a company by domain.

See https://developer.tomba.io/#company-enrichment

pub fn combined_find(&self, email: &str) -> Result<TombaResponse, TombaError>

Combined person + company enrichment.

See https://developer.tomba.io/#combined-enrichment

Source

impl Tomba

pub fn email_finder( &self, domain: &str, first_name: &str, last_name: &str, webhook_url: Option<&str>, ) -> Result<TombaResponse, TombaError>

Find the most likely email address for a person at a company.

See https://developer.tomba.io/#email-finder

pub fn author_finder( &self, url: &str, webhook_url: Option<&str>, ) -> Result<TombaResponse, TombaError>

Find the email address of the author of a blog post.

See https://developer.tomba.io/#author-finder

pub fn linkedin_finder( &self, url: &str, enrich_mobile: Option<bool>, full: Option<bool>, webhook_url: Option<&str>, ) -> Result<TombaResponse, TombaError>

Find the email address from a LinkedIn URL.

See https://developer.tomba.io/#linkedin-finder

pub fn email_enrichment( &self, email: &str, webhook_url: Option<&str>, ) -> Result<TombaResponse, TombaError>

Enrich a person by email address.

See https://developer.tomba.io/#email-enrichment

Source

impl Tomba

Source

impl Tomba

pub fn email_format(&self, domain: &str) -> Result<TombaResponse, TombaError>

Detect the email format used by a company.

See https://developer.tomba.io/#email-format

Source

impl Tomba

Source

impl Tomba

pub fn list_leads( &self, domain: Option<&str>, ) -> Result<TombaResponse, TombaError>

pub fn get_lead(&self, id: &str) -> Result<TombaResponse, TombaError>

Get a single lead by ID.

See https://developer.tomba.io/#get-a-lead

pub fn create_lead(&self, body: &Value) -> Result<TombaResponse, TombaError>

pub fn update_lead( &self, id: &str, body: &Value, ) -> Result<TombaResponse, TombaError>

Update an existing lead.

See https://developer.tomba.io/#update-a-lead

pub fn delete_lead(&self, id: &str) -> Result<TombaResponse, TombaError>

Source

impl Tomba

Source

impl Tomba

Source

impl Tomba

pub fn get_location(&self, country: &str) -> Result<TombaResponse, TombaError>

Get location details for a country code.

See https://developer.tomba.io/#location

Source

impl Tomba

pub fn logs( &self, page: Option<u32>, limit: Option<u32>, ) -> Result<TombaResponse, TombaError>

Return the last 1 000 API requests made in the past 3 months.

See https://developer.tomba.io/#logs

Source

impl Tomba

pub fn phone_finder( &self, email: &str, webhook_url: Option<&str>, ) -> Result<TombaResponse, TombaError>

Find a phone number using an email address.

See https://developer.tomba.io/#phone-finder

pub fn phone_validator(&self, phone: &str) -> Result<TombaResponse, TombaError>

Validate a phone number.

See https://developer.tomba.io/#phone-validator

Source

impl Tomba

Search for companies matching the given criteria.

See https://developer.tomba.io/#companies-search

Source

impl Tomba

pub fn similar_domains(&self, domain: &str) -> Result<TombaResponse, TombaError>

Find domains similar to the given one.

See https://developer.tomba.io/#similar

Source

impl Tomba

pub fn email_sources(&self, email: &str) -> Result<TombaResponse, TombaError>

Find the web sources where an email address has been found.

See https://developer.tomba.io/#email-sources

Source

impl Tomba

pub fn status(&self, domain: &str) -> Result<TombaResponse, TombaError>

Check whether a domain is a webmail or disposable provider.

See https://developer.tomba.io/#domain-status

pub fn autocomplete(&self, query: &str) -> Result<TombaResponse, TombaError>

Auto-complete company names and retrieve logo and domain information.

See https://developer.tomba.io/#autocomplete

Source

impl Tomba

pub fn technology_check( &self, domain: &str, ) -> Result<TombaResponse, TombaError>

Check what technologies a website uses.

See https://developer.tomba.io/#technology-checker

Source

impl Tomba

pub fn init(config: TombaConfig) -> Result<Self, TombaError>

Create a new Tomba client.

Examples
use tomba::{Tomba, TombaConfig};

let config = TombaConfig {
    key: "ta_xxxx".to_string(),
    secret: "ts_xxxx".to_string(),
};
let mut tomba = Tomba::init(config).expect("should construct");
pub fn call( &self, method: &str, path: &str, params: &HashMap<String, String>, ) -> Result<TombaResponse, TombaError>

Send a request with query parameters (GET / DELETE).

  • method"GET" or "DELETE"
  • path – path relative to the base URL, e.g. "me"
  • params – query-string key/value pairs
pub fn call_json( &self, method: &str, path: &str, body: &Value, ) -> Result<TombaResponse, TombaError>

Send a request with a JSON body (POST / PUT).

  • method"POST" or "PUT"
  • path – path relative to the base URL
  • body – JSON value to send as the request body
Source

impl Tomba

pub fn usage(&self) -> Result<TombaResponse, TombaError>

Return your monthly request usage.

See https://developer.tomba.io/#usage

Source

impl Tomba

pub fn email_verifier( &self, email: &str, webhook_url: Option<&str>, enrich_mobile: Option<bool>, ) -> Result<TombaResponse, TombaError>

Verify the deliverability of an email address.

See https://developer.tomba.io/#email-verifier